
-- return the window size
function getWindowSize()
	return 640, 140
end

-- return the main font
-- the return is a list of font filename and size options
-- the first one found will be used
function getFont()
	if isMac then
		return { { name="GillSans.dfont", size=14 }, { name="Monaco.dfont", size=12 } }
	else
		return { { name="tahoma.ttf", size=14 }, { name="arial.ttf", size=12 } }
	end
end
-- return the label font
function getLabelFont()
	if isMac then
		return { { name="GillSans.dfont", size=11 }, { name="Monaco.dfont", size=9 } }
	else
		return { { name="tahoma.ttf", size=11 }, { name="arial.ttf", size=9 } }
	end
end
-- return the text field font
function getTextFieldFont()
	if isMac then
		return { { name="GillSans.dfont", size=12 }, { name="Monaco.dfont", size=10 } }
	else
		return { { name="tahoma.ttf", size=12 }, { name="arial.ttf", size=10 } }
	end
end

-- create and lay out all the controls
function createUI()

	-- load textures
	atlas = texture( "buttons.png" )
	background = texture( "background.png" )
	setBackgroundTexture( background )

	local windowW, windowH = getWindowSize()
	
	-- set location of the banner
	setBannerPosition( windowH-20 )
	
	-- set outline colours for groups
	setGroupActiveColour( 0.95, 0.9, 0.9, 1.0 )
	setGroupInactiveColour( 0.8, 0.4, 0.01, 1.0 )
	
	-- constants
	local pad = 10.0
	local kMeterW = 5
	local kMeterH = 69
	local kTriggerLvlPadH = 4.0
	local kMeterDrop = 14.0
	local kMeterPadH = 2.0
	local kPitchButtonW = 16
	local kPitchButtonH = 14
	local kTextFieldH = 12
	local kKnobSize = 42
	local kKnobSpace = 54
	local kEditTextH = 11
	local kSmallKnobSize = 16
	local kButtonW = 48
	local kButtonH = 32
	local kButtonSpaceH = 58
	local kButtonSpaceV = 42
	local kSmallIndicatorSpace = 20
		
	-- make renderers
	theKnobRenderer = knobRenderer( atlas, 6*kButtonW+1, 2*kButtonH+1, kKnobSize )
	theButtonRenderer = buttonRenderer( atlas )
	theSliderRenderer = sliderRenderer( atlas )

	-- buttons

	loopButtonsGroup = group( "Loop" )
	loopButtonsGroup:add( paramButton( "Tap Tempo",		0*kButtonSpaceH, 0*kButtonSpaceV, kButtonW, kButtonH, 3*kButtonW, 2*kButtonH ) )
	loopButtonsGroup:add( paramButton( "Tap Record",	0*kButtonSpaceH, 1*kButtonSpaceV, kButtonW, kButtonH, 4*kButtonW, 2*kButtonH ) )
	loopButtonsGroup:add( paramButton( "Freeze Loop",	1*kButtonSpaceH, 1*kButtonSpaceV, kButtonW, kButtonH, 7*kButtonW, 0*kButtonH ) )
	loopButtonsGroup:add( paramButton( "Clear Loop",	1*kButtonSpaceH, 0*kButtonSpaceV, kButtonW, kButtonH, 3*kButtonW, 0*kButtonH ) )
	
	miscButtonsGroup = group( "Misc" )
	miscButtonsGroup:add( button( "Prefs", "Prefs",			0*kButtonSpaceH, 0, kButtonW, kButtonH, 0*kButtonW, 0*kButtonH ) )
	
	-- knobs
	
	local function knobAndTextField( group, param, label, x, y, size, textH, textW )
		textW = textW or size
		local knobx = x + 0.5 * ( textW - size )
		group:add( knob( param, "", knobx, y+textH+1, size ) )
		group:add( textField( param, label, x, y, textW, textH ) )
	end
	
	masterLevelGroup = group( "Master" )
	knobAndTextField( masterLevelGroup, "Master feedback", "Feedback", 0*kKnobSpace, 0, kKnobSize, kTextFieldH )

	levelsGroup = group( "Levels" )
	knobAndTextField( levelsGroup, "Dry Level", 	"Dry", 		0*kButtonSpaceH, 0, kKnobSize, kTextFieldH )
	knobAndTextField( levelsGroup, "Effect Level", 	"Effect", 	1*kButtonSpaceH, 0, kKnobSize, kTextFieldH )
	knobAndTextField( levelsGroup, "Input Level", 	"Input", 	2*kButtonSpaceH, 0, kKnobSize, kTextFieldH )

	OSCGroup = group( "OSC" )
	knobAndTextField( OSCGroup, "OSC Port Offset", 	"Port", 	0, 0, kKnobSize, kTextFieldH )
	
	-- positions!
	
	local left = 20.0
	local ight = windowW - 20.0
	
	local x = left
	local y = left
	
	local theValueDisplay = valueDisplay()
	theValueDisplay:setColour( 1, 1, 1, 1 )
	
	loopButtonsGroup:setPosition( x, y )
	x = x + loopButtonsGroup:width() + pad
	
	miscButtonsGroup:setPosition( x, y )
	x = x + miscButtonsGroup:width() + pad
	y = y + 10
	
	levelsGroup:setPosition( x, y )
	x = x + levelsGroup:width() + pad
	
	masterLevelGroup:setPosition( x, y )
	x = x + masterLevelGroup:width() + pad
	
	OSCGroup:setPosition( x, y )
	x = x + OSCGroup:width() + pad
	
	x = x - 15
	theValueDisplay:setPosition( "Tempo", x, y+22, kKnobSize+10, 12 )
	theValueDisplay:setPosition( "DelayTime", x, y-10, kKnobSize+10, 12 )
	theValueDisplay:setPosition( "DelayBeats", x, y+6, kKnobSize+10, 12 )
	theValueDisplay:setPosition( "EnvLevel", x, y+38, kKnobSize+10, 12 )
		
	-- positions done
	
	-- meters
	
	x = x + kKnobSize+10 + 5
	y = y - kMeterDrop
	
	meters = levelMeters( atlas, 512-5, 0, kMeterW, kMeterH )
	meters:add( "InputRmsLeft", x, y )
	x = x + kMeterW
	meters:add( "InputRmsRight", x, y )
	x = x + kMeterW
	x = x + 2*kMeterPadH
	meters:add( "FxRmsLeft", x, y )
	x = x + kMeterW
	meters:add( "FxRmsRight", x, y )

end		-- of createUI()
